@@ -7,6 +7,7 @@
 #include <qpdf/Constants.h>
 #include <qpdf/Types.h>
 #include <qpdf/DLL.h>
+#include <qpdf/Pl_String.hh>
 #include <qpdf/QPDFExc.hh>
 #include <qpdf/QPDFObjGen.hh>
 #include <qpdf/QPDFXRefEntry.hh>
@@ -302,7 +303,7 @@ void init_object(py::module_ &m)
         .value("operator", qpdf_object_type_e::ot_operator)
         .value("inlineimage", qpdf_object_type_e::ot_inlineimage);
 
-    py::class_<Buffer, std::shared_ptr<Buffer>>(m, "Buffer", py::buffer_protocol())
+    py::class_<Buffer, py::smart_holder>(m, "Buffer", py::buffer_protocol())
         .def_buffer([](Buffer &b) -> py::buffer_info {
             return py::buffer_info(b.getBuffer(),
                 sizeof(unsigned char),
@@ -820,7 +821,10 @@ void init_object(py::module_ &m)
             [](QPDFObjectHandle &h,
                 bool dereference   = false,
                 int schema_version = 2) -> py::bytes {
-                return h.getJSON(schema_version, dereference).unparse();
+                std::string result;
+                Pl_String p("json", nullptr, result);
+                h.writeJSON(schema_version, &p, dereference);
+                return result;
             },
             py::arg("dereference")    = false,
             py::arg("schema_version") = 2); // end of QPDFObjectHandle bindings
@@ -878,10 +882,8 @@ void init_object(py::module_ &m)
 
     // Since QPDFEmbeddedFileDocumentHelper::getEmbeddedFiles returns
     // std::map<std::string, std::shared_ptr<QPDFFileSpecObjectHelper>>
-    // we must ensure that the entire QPDFObjectHelper type hierarchy is held in
-    // std::shared_ptr or repackage that interface so it does not return a
-    // std::shared_ptr<QPDFFileSpecObjectHelper>> to Python.
-    py::class_<QPDFObjectHelper, std::shared_ptr<QPDFObjectHelper>>(m, "ObjectHelper")
+    // we must use smart_holder.
+    py::class_<QPDFObjectHelper, py::smart_holder>(m, "ObjectHelper")
         .def(
             "__eq__",
             [](QPDFObjectHelper &self, QPDFObjectHelper &other) {
