@@ -31,7 +31,6 @@ from pikepdf import (
     Object,
     Operator,
     Pdf,
-    PdfError,
     Stream,
     String,
 )
@@ -119,7 +118,7 @@ def test_decimal_from_float(f):
 
         assert isclose(py_d, d, abs_tol=1e-5), (d, f.hex())
     else:
-        with pytest.raises(PdfError), pytest.deprecated_call():
+        with pytest.raises(TypeError):
             Object.parse(str(d))
 
 
@@ -593,9 +592,9 @@ class TestStream:
     def test_stream_refcount(self, refcount, outpdf):
         pdf = pikepdf.new()
         stream = Stream(pdf, b'blahblah')
-        assert refcount(stream) == 2
+        count = refcount(stream)
         pdf.Root.SomeStream = stream
-        assert refcount(stream) == 2
+        assert refcount(stream) == count
         del stream
         pdf.save(outpdf)
         with pikepdf.open(outpdf) as pdf2:
